@@ -1,4 +1,4 @@
-VERSION = '0.2.2'
+VERSION = '0.2.3'
 
 BROADCAST_MSG = bytearray([
     0x5a, 0x5a, 0x01, 0x11, 0x48, 0x00, 0x92, 0x00,
@@ -29,4 +29,9 @@ MSGTYPE_ENCRYPTED_REQUEST = 0x6
 MSGTYPE_TRANSPARENT = 0xf
 
 OPEN_MIDEA_APP_ACCOUNT = 'midea_is_best@outlook.com'
-OPEN_MIDEA_APP_PASSWORD = 'lovemidea4ever' 
\ No newline at end of file
+OPEN_MIDEA_APP_PASSWORD = 'lovemidea4ever' 
+
+CMD_TYPE_CONTROL = 0x02
+CMD_TYPE_QUERRY = 0x03
+CMD_TYPE_REPORT = 0x04
+CMD_TYPE_ABNL_REPORT = 0x06
\ No newline at end of file
